summaryrefslogtreecommitdiff
path: root/src/util/taler-exchange-secmod-rsa.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/util/taler-exchange-secmod-rsa.h')
-rw-r--r--src/util/taler-exchange-secmod-rsa.h42
1 files changed, 34 insertions, 8 deletions
diff --git a/src/util/taler-exchange-secmod-rsa.h b/src/util/taler-exchange-secmod-rsa.h
index 146b6948f..ffbceb48e 100644
--- a/src/util/taler-exchange-secmod-rsa.h
+++ b/src/util/taler-exchange-secmod-rsa.h
@@ -1,6 +1,6 @@
/*
This file is part of TALER
- Copyright (C) 2020 Taler Systems SA
+ Copyright (C) 2020-2022 Taler Systems SA
TALER is free software; you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
@@ -24,17 +24,21 @@
#define TALER_HELPER_RSA_MT_PURGE 1
#define TALER_HELPER_RSA_MT_AVAIL 2
+#define TALER_HELPER_RSA_MT_REQ_BATCH_SIGN 3
#define TALER_HELPER_RSA_MT_REQ_INIT 4
#define TALER_HELPER_RSA_MT_REQ_SIGN 5
#define TALER_HELPER_RSA_MT_REQ_REVOKE 6
#define TALER_HELPER_RSA_MT_RES_SIGNATURE 7
#define TALER_HELPER_RSA_MT_RES_SIGN_FAILURE 8
+#define TALER_HELPER_RSA_MT_RES_BATCH_FAILURE 9
+
+#define TALER_HELPER_RSA_SYNCED 10
-#define TALER_HELPER_RSA_SYNCED 9
GNUNET_NETWORK_STRUCT_BEGIN
+
/**
* Message sent if a key is available.
*/
@@ -58,7 +62,7 @@ struct TALER_CRYPTO_RsaKeyAvailableNotification
/**
* When does the key become available?
*/
- struct GNUNET_TIME_AbsoluteNBO anchor_time;
+ struct GNUNET_TIME_TimestampNBO anchor_time;
/**
* How long is the key available after @e anchor_time?
@@ -72,11 +76,11 @@ struct TALER_CRYPTO_RsaKeyAvailableNotification
/**
* Signature affirming the announcement, of
- * purpose #TALER_SIGNATURE_SM_DENOMINATION_KEY.
+ * purpose #TALER_SIGNATURE_SM_RSA_DENOMINATION_KEY.
*/
struct TALER_SecurityModuleSignatureP secm_sig;
/* followed by @e pub_size bytes of the public key */
/* followed by @e section_name bytes of the configuration section name
of the denomination of this key */
@@ -102,7 +106,7 @@ struct TALER_CRYPTO_RsaKeyPurgeNotification
/**
* Hash of the public key of the purged RSA key.
*/
- struct GNUNET_HashCode h_denom_pub;
+ struct TALER_RsaPubHashP h_rsa;
};
@@ -125,13 +129,35 @@ struct TALER_CRYPTO_SignRequest
/**
* Hash of the public key of the RSA key to use for the signature.
*/
- struct GNUNET_HashCode h_denom_pub;
+ struct TALER_RsaPubHashP h_rsa;
/* followed by message to sign */
};
/**
+ * Message sent if a batch of signatures is requested.
+ */
+struct TALER_CRYPTO_BatchSignRequest
+{
+ /**
+ * Type is #TALER_HELPER_RSA_MT_REQ_BATCH_SIGN.
+ */
+ struct GNUNET_MessageHeader header;
+
+ /**
+ * Number of signatures to create, in NBO.
+ */
+ uint32_t batch_size;
+
+ /*
+ * Followed by @e batch_size sign requests.
+ */
+
+};
+
+
+/**
* Message sent if a key was revoked.
*/
struct TALER_CRYPTO_RevokeRequest
@@ -149,7 +175,7 @@ struct TALER_CRYPTO_RevokeRequest
/**
* Hash of the public key of the revoked RSA key.
*/
- struct GNUNET_HashCode h_denom_pub;
+ struct TALER_RsaPubHashP h_rsa;
};
@@ -72,11 +76,11 @@ struct TALER_CRYPTO_RsaKeyAvailableNotification
*/
struct TALER_SecurityModuleSignatureP secm_sig;
- /* followed by @e pub_size bytes of the public key */
+ /* followed by @e pub_size bytes of the RSA public key */
/* followed by @e section_name bytes of the configuration section name
of the denomination of this key */